package com.zbf.system.service;

import java.util.List;
import com.zbf.system.domain.TMiStockBak;

/**
 * 库存备份Service接口
 *
 * @author tony
 * @date 2024-06-14
 */
public interface ITMiStockBakService
{
    /**
     * 查询库存备份
     *
     * @param id 库存备份主键
     * @return 库存备份
     */
    public TMiStockBak selectTMiStockBakById(Long id);

    /**
     * 查询库存备份列表
     *
     * @param tMiStockBak 库存备份
     * @return 库存备份集合
     */
    public List<TMiStockBak> selectTMiStockBakList(TMiStockBak tMiStockBak);

    /**
     * 新增库存备份
     *
     * @param tMiStockBak 库存备份
     * @return 结果
     */
    public int insertTMiStockBak(TMiStockBak tMiStockBak);

    /**
     * 修改库存备份
     *
     * @param tMiStockBak 库存备份
     * @return 结果
     */
    public int updateTMiStockBak(TMiStockBak tMiStockBak);

    /**
     * 批量删除库存备份
     *
     * @param ids 需要删除的库存备份主键集合
     * @return 结果
     */
    public int deleteTMiStockBakByIds(Long[] ids);

    /**
     * 删除库存备份信息
     *
     * @param id 库存备份主键
     * @return 结果
     */
    public int deleteTMiStockBakById(Long id);

    /**
     * 批量禁用库存备份
     *
     * @param ids 需要禁用的库存备份主键集合
     * @return 结果
     */
    public int disabledTMiStockBakByIds(Long[] ids);

    /**
     * 批量启用库存备份
     *
     * @param ids 需要启用的库存备份主键集合
     * @return 结果
     */
    public int enableTMiStockBakByIds(Long[] ids);

    /**
     * 改变状态
     *
     * @param tMiStockBak
     * @return 结果
     */
    public int updateStatus(TMiStockBak tMiStockBak);
}

